package come.stormborntales.notevault.ui.screens

import android.content.Context
import android.graphics.BitmapFactory
import android.graphics.ImageDecoder
import android.media.Image
import android.net.Uri
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.ImageBitmap
import androidx.compose.ui.graphics.asImageBitmap
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import come.stormborntales.notevault.data.model.NoteEntry
import java.io.InputStream

fun loadImageBitmap(context: Context, uri: Uri): ImageBitmap? {
    return try {
        val inputStream: InputStream? = context.contentResolver.openInputStream(uri)
        val bitmap = BitmapFactory.decodeStream(inputStream)
        bitmap?.asImageBitmap()
    } catch (e: Exception) {
        e.printStackTrace()
        null
    }
}

fun getFileNameFromUri(context: Context, uri: Uri): String? {
    val cursor = context.contentResolver.query(uri, null, null, null, null)
    cursor?.use {
        val nameIndex = it.getColumnIndex(android.provider.OpenableColumns.DISPLAY_NAME)
        if (it.moveToFirst() && nameIndex >= 0) {
            return it.getString(nameIndex)
        }
    }
    return null
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun MainScreen(
    onAddNoteClicked: () -> Unit, // Übergib hier deine Logik für den Import
    notes: MutableList<NoteEntry>, // Liste der Notenbilder (hier als URI),
) {
    val dummyNotes = notes
    // Hole den aktuellen Context
    val context = LocalContext.current
    Scaffold(
        topBar = {
            TopAppBar(
                title = { Text("Meine Noten") }
            )
        },
        floatingActionButton = {
            FloatingActionButton(
                onClick = onAddNoteClicked
            ) {
                Icon(Icons.Default.Add, contentDescription = "Neue Noten hinzufügen")
            }
        },
        floatingActionButtonPosition = FabPosition.End
    ) { innerPadding ->
        LazyColumn(
            contentPadding = innerPadding,
            modifier = Modifier
                .fillMaxSize()
                .padding(16.dp)
        ) {
            items(dummyNotes) { noteUri ->
                val imageBitmap = loadImageBitmap(context, noteUri.images[0])
                val fileName = noteUri.title

                if (imageBitmap != null) {
                    Card(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(8.dp),
                        elevation = CardDefaults.cardElevation(4.dp)
                    ) {
                        Row(modifier = Modifier.padding(8.dp)) {
                            Image(
                                bitmap = imageBitmap,
                                contentDescription = "Notenblatt Vorschau",
                                modifier = Modifier
                                    .size(80.dp) // oder width = 80.dp, height = 100.dp
                                    .padding(end = 8.dp)
                            )
                            Text(
                                text = fileName ?: "Unbekannter Dateiname",
                                style = MaterialTheme.typography.bodyMedium,
                                modifier = Modifier.weight(2f)
                            )
                        }
                    }
                }
            }
        }
    }



}